@@ -1,7 +1,9 @@
 import os
 
+from conan.internal.api.local.editable import EditablePackages
 from conan.internal.cache.cache import PkgCache
 from conan.internal.cache.home_paths import HomePaths
+from conan.internal.model.conf import ConfDefinition
 from conans.client.graph.proxy import ConanProxy
 from conans.client.graph.python_requires import PyRequireLoader
 from conans.client.graph.range_resolver import RangeResolver
@@ -42,6 +44,7 @@ class ConanBasicApp:
         """
         global_conf = conan_api.config.global_conf
         self.global_conf = global_conf
+        self.conan_api = conan_api
         cache_folder = conan_api.home_folder
         self.cache_folder = cache_folder
         self.cache = PkgCache(self.cache_folder, global_conf)
@@ -69,3 +72,22 @@ class ConanApp(ConanBasicApp):
         conanfile_helpers = ConanFileHelpers(conan_api.remotes.requester, cmd_wrap, self.global_conf,
                                              self.cache, self.cache_folder)
         self.loader = ConanFileLoader(self.pyreq_loader, conanfile_helpers)
+
+
+class LocalRecipesIndexApp:
+    """
+    Simplified one, without full API, for the LocalRecipesIndex. Only publicly used fields are:
+    - cache
+    - loader (for the export phase of local-recipes-index)
+    The others are internally use by other collaborators
+    """
+    def __init__(self, cache_folder):
+        self.global_conf = ConfDefinition()
+        self.cache = PkgCache(cache_folder, self.global_conf)
+        self.remote_manager = RemoteManager(self.cache, auth_manager=None, home_folder=cache_folder)
+        editable_packages = EditablePackages()
+        self.proxy = ConanProxy(self, editable_packages)
+        self.range_resolver = RangeResolver(self, self.global_conf, editable_packages)
+        pyreq_loader = PyRequireLoader(self, self.global_conf)
+        helpers = ConanFileHelpers(None, CmdWrapper(""), self.global_conf, self.cache, cache_folder)
+        self.loader = ConanFileLoader(pyreq_loader, helpers)
