@@ -1,6 +1,6 @@
 from conan.api.output import ConanOutput
 from conan.tools.build.flags import cppstd_msvc_flag
-from conans.model.options import _PackageOption
+from conan.internal.model.options import _PackageOption
 
 __all__ = ["to_meson_machine", "to_meson_value", "to_cppstd_flag", "to_cstd_flag"]
 
@@ -18,7 +18,7 @@ _meson_system_map = {
     'SunOS': 'sunos',
     'Windows': 'windows',
     'WindowsCE': 'windows',
-    'WindowsStore': 'windows'
+    'WindowsStore': 'windows',
 }
 
 # https://mesonbuild.com/Reference-tables.html#cpu-families
@@ -68,6 +68,17 @@ _cppstd_map = {
 }
 
 
+def get_apple_subsystem(apple_sdk):
+    return {
+        "iphoneos": "ios",
+        "iphonesimulator": "ios-simulator",
+        "appletvos": "tvos",
+        "appletvsimulator": "tvos-simulator",
+        "watchos": "watchos",
+        "watchsimulator": "watchos-simulator",
+    }.get(apple_sdk, "macos")
+
+
 def to_meson_machine(machine_os, machine_arch):
     """Gets the OS system info as the Meson machine context.
 
